@@ -6,10 +6,10 @@
 # accept "$" in the username.  This script may be used for the
 # "add machine script" in smb.conf.
 
-awkprog="/usr/pkg/bin/nawk"
+awkprog="/usr/bin/gawk"
 catprog="/bin/cat"
 mktempprog="/usr/bin/mktemp"
-pwdmkdbprog=""
+pwdmkdbprog="pwd_mkdb"
 rmprog="/bin/rm"
 
 progname=adduser
