@@ -5,9 +5,9 @@
 # This is a deluser script for NetBSD systems whose userdel(8) doesn't
 # accept "$" in the username.
 
-awkprog="/usr/pkg/bin/nawk"
+awkprog="/usr/bin/gawk"
 mktempprog="/usr/bin/mktemp"
-pwdmkdbprog=""
+pwdmkdbprog="pwd_mkdb"
 rmprog="/bin/rm"
 
 progname=deluser
